@@ -31,7 +31,7 @@ except ImportError as e:
         'https://safetyculture.github.io/iauditor-exporter/script-setup/installing-packages/')
     sys.exit()
 
-install()
+# install()
 
 
 def sync_exports(logger, settings, sc_client):
@@ -63,9 +63,8 @@ def sync_exports(logger, settings, sc_client):
         return
     if 'sql' in settings[EXPORT_FORMATS]:
         get_started = sql_setup(logger, settings, 'audit')
-        last_successful = query_max_last_modified(get_started[1], get_started[2])
-        # print(last_successful)
-        # last_successful = get_last_successful(logger, settings[CONFIG_NAME])
+        # last_successful = query_max_last_modified(get_started[1], get_started[2])
+        last_successful = get_last_successful(logger, settings[CONFIG_NAME])
     else:
         last_successful = get_last_successful(logger, settings[CONFIG_NAME])
     if settings[TEMPLATE_IDS] is not None:
@@ -96,9 +95,8 @@ def sync_exports(logger, settings, sc_client):
                     get_started = sql_setup(logger, settings, 'audit')
                 if export_format == 'csv':
                     get_started = 'csv'
-                chunks_to_process = sc_client.chunks(audits_to_process, 500)
-                for chunk in chunks_to_process:
-                    loop_through_chunks(chunk, logger, settings, sc_client, export_count, export_total, get_started)
+                chunks_to_process = sc_client.chunks(audits_to_process, 50)
+                loop_through_chunks(chunks_to_process, logger, settings, sc_client, export_count, export_total, get_started)
                 if get_started not in ['csv', 'ignored']:
                     end_session(get_started[1])
             else:
@@ -110,12 +108,13 @@ def sync_exports(logger, settings, sc_client):
                     end_session(get_started[1])
 
 
-def loop_through_chunks(audits_to_process, logger, settings, sc_client, export_count, export_total, get_started):
-    audits_to_process = sc_client.raise_pool(audits_to_process, logger)
-    for audit in audits_to_process:
-        logger.info('Processing audit (' + str(export_count) + '/' + str(export_total) + ')')
-        process_audit(logger, settings, sc_client, audit, get_started)
-        export_count += 1
+def loop_through_chunks(chunks_to_process, logger, settings, sc_client, export_count, export_total, get_started):
+    for chunk in chunks_to_process:
+        audits_to_process = sc_client.raise_pool(chunk)
+        for audit in audits_to_process:
+            logger.info('Processing audit (' + str(export_count) + '/' + str(export_total) + ')')
+            process_audit(logger, settings, sc_client, audit, get_started)
+            export_count += 1
 
 
 def process_audit(logger, settings, sc_client, audit, get_started):
