@@ -1,4 +1,4 @@
-from sqlalchemy import Column, String, Integer, Float, DateTime, Boolean, BigInteger, Text
+from sqlalchemy import Column, String, Integer, Float, DateTime, Boolean, BigInteger, Unicode
 
 
 def set_table(table, merge, Base):
@@ -6,10 +6,10 @@ def set_table(table, merge, Base):
         __tablename__ = table
         SortingIndex = Column(Integer)
         ItemType = Column(String(20))
-        Label = Column(Text())
-        Response = Column(Text())
-        Comment = Column(Text())
-        MediaHypertextReference = Column(Text())
+        Label = Column(Unicode())
+        Response = Column(Unicode())
+        Comment = Column(Unicode())
+        MediaHypertextReference = Column(Unicode())
         Latitude = Column(String(50))
         Longitude = Column(String(50))
         ItemScore = Column(Float)
@@ -24,13 +24,13 @@ def set_table(table, merge, Base):
             DatePK = Column(BigInteger, primary_key=True, autoincrement=False)
         else:
             DatePK = Column(BigInteger)
-        ResponseID = Column(Text())
+        ResponseID = Column(Unicode())
         ParentID = Column(String(100))
-        AuditOwner = Column(Text())
-        AuditAuthor = Column(Text())
-        AuditOwnerID = Column(Text())
+        AuditOwner = Column(Unicode())
+        AuditAuthor = Column(Unicode())
+        AuditOwnerID = Column(Unicode())
         AuditAuthorID = Column(String(100))
-        AuditName = Column(Text())
+        AuditName = Column(Unicode())
         AuditScore = Column(Float)
         AuditMaxScore = Column(Float)
         AuditScorePercentage = Column(Float)
@@ -39,20 +39,20 @@ def set_table(table, merge, Base):
         DateCompleted = Column(DateTime)
         DateModified = Column(DateTime)
         TemplateID = Column(String(100))
-        TemplateName = Column(Text())
-        TemplateAuthor = Column(Text())
+        TemplateName = Column(Unicode())
+        TemplateAuthor = Column(Unicode())
         TemplateAuthorID = Column(String(100))
-        ItemCategory = Column(Text())
+        ItemCategory = Column(Unicode())
         RepeatingSectionParentID = Column(String(100))
-        DocumentNo = Column(Text())
+        DocumentNo = Column(Unicode())
         ConductedOn = Column(DateTime)
-        PreparedBy = Column(Text())
-        Location = Column(Text())
-        Personnel = Column(Text())
-        ClientSite = Column(Text())
-        AuditSite = Column(Text())
-        AuditArea = Column(Text())
-        AuditRegion = Column(Text())
+        PreparedBy = Column(Unicode())
+        Location = Column(Unicode())
+        Personnel = Column(Unicode())
+        ClientSite = Column(Unicode())
+        AuditSite = Column(Unicode())
+        AuditArea = Column(Unicode())
+        AuditRegion = Column(Unicode())
         Archived = Column(Boolean)
     return Database
 
@@ -111,9 +111,9 @@ def set_actions_table(table, merge, Base):
     class ActionsDatabase(Base):
         __tablename__ = table
         id = Column(Integer, primary_key=False, autoincrement=True)
-        description = Column(Text())
-        assignee = Column(Text())
-        priority = Column(Text())
+        description = Column(Unicode())
+        assignee = Column(Unicode())
+        priority = Column(Unicode())
         priorityCode = Column(Integer)
         status = Column(String(20))
         statusCode = Column(Integer)
@@ -123,11 +123,11 @@ def set_actions_table(table, merge, Base):
             DatePK = Column(BigInteger, autoincrement=False)
         else:
             DatePK = Column(BigInteger, primary_key=True, autoincrement=False)
-        audit = Column(Text())
+        audit = Column(Unicode())
         auditId = Column(String(50))
-        linkedToItem = Column(Text())
-        linkedToItemId = Column(Text())
-        creatorName = Column(Text())
+        linkedToItem = Column(Unicode())
+        linkedToItemId = Column(Unicode())
+        creatorName = Column(Unicode())
         creatorId = Column(String(50))
         createdDatetime = Column(DateTime)
         modifiedDatetime = Column(DateTime)
