@@ -9,8 +9,8 @@ from yaml.scanner import ScannerError
 from modules.global_variables import *
 from modules.last_successful import get_last_successful, parse_ls, update_sync_marker_file
 from modules.logger import log_critical_error, create_directory_if_not_exists
-# from safetypy import safetypy as sp
-import modules.safetypy as sp
+from safetypy import safetypy as sp
+# import modules.safetypy as sp
 from modules.setup_questions import questions, flat_config, model_config
 from modules.sql import test_sql_settings
 
@@ -501,31 +501,10 @@ def parse_command_line_arguments(logger):
     parser.add_argument('--list_preferences', nargs='*', help='display all preferences, or restrict to specific'
                                                               ' template_id if supplied as additional argument')
     parser.add_argument('--loop', nargs='*', help='execute continuously until interrupted')
-    parser.add_argument('--setup', action='store_true', help='Automatically create new directory containing the '
-                                                             'necessary config file.'
-                                                             'Directory will be named iAuditor Audit Exports, and will '
-                                                             'be placed in your current directory')
+    parser.add_argument('--setup', action='store_true', help='Helps set up the script with ease.')
     args = parser.parse_args()
-
+    
     if args.setup:
-        logo = '''
-                               *****                      
-                             *******##(                   
-                          ********#######                 
-                        *******     ########              
-                     ********         *#####              
-                  ,*******                                
-                ********                      *****       
-               ******                       *******.      
-                                         ********         
-                        ///            ********           
-                       //////*      ********              
-                        ////////  ********                
-                           /////*******                   
-                             *******,                     
-
-              Thanks for using the iAuditor Exporter!'''
-        print(Panel(logo, box=box.SIMPLE, expand=False))
         initial_setup(logger)
         exit()
 
@@ -546,8 +525,6 @@ def parse_command_line_arguments(logger):
     else:
         config_filename = None
 
-
-
     export_formats = ['pdf']
     if args.format is not None and len(args.format) > 0:
         valid_export_formats = ['json', 'docx', 'pdf', 'csv', 'media', 'web-report-link', 'actions', 'actions-sql',
@@ -710,8 +687,6 @@ def modify_choice(logger, settings, config_path):
             for inner_k, inner_v in v.items():
                 if inner_k == 'sql_table':
                     options.append(Separator())
-                if inner_k == 'token':
-                    inner_k = f'{inner_k} - (Required)'
                 options.append(f'{inner_k} - Current setting: {inner_v}')
     print('Which setting do you need to modify?')
     exit_no_save = 'Exit without saving changes'
@@ -719,7 +694,7 @@ def modify_choice(logger, settings, config_path):
     if exit_no_save not in options:
         exit_list = [exit_save, exit_no_save, Separator()]
         options = exit_list + options
-    to_modify = questionary.select('Select the config option you want to change:', choices=options).ask()
+    to_modify = questionary.select("Select an option to modify:", choices=options).ask()
     to_modify = to_modify.split('-')[0].strip()
     if to_modify == exit_save:
         with open(config_path, 'w') as file:
@@ -750,6 +725,7 @@ def initial_setup(logger):
 
     # setup variables
     current_directory_path = os.getcwd()
+    print('Setup!')
     exports_folder_name = 'configs'
 
     create_directory_if_not_exists(logger, exports_folder_name)
@@ -772,10 +748,7 @@ def initial_setup(logger):
         config_to_edit = 'config.yaml'
         config_path = os.path.join(exports_folder_name, config_to_edit)
     if 'config_name' in settings:
-        if settings['config_name']:
-            config_name = settings['config_name']
-        else:
-            config_name = 'iauditor'
+        config_name = settings['config_name']
     else:
         print('Your config file is missing config_name. Delete the file, '
               're run the tool and it will be recreated correctly.')
@@ -785,7 +758,8 @@ def initial_setup(logger):
     if parsed_date:
         pretty_file_name = parsed_date.strftime("%Y-%m-%d at %H%M")
 
-        update_ls_q = ask_question(logger, f'''We are currently searching for inspections completed after {pretty_file_name}, would you like to change this? Please note: if you're exporting with SQL, we'll grab this date by querying the database so changing this won't change anything for SQL exports.''', 'bool')
+        update_ls_q = ask_question(logger, f'We are currently searching for inspections completed after {pretty_file_name}, would you '
+              f'like to change this?', 'bool')
         if update_ls_q:
             print(box_print('''
             You can use natural language here. For example if you wanted to start the search from March 22nd 2018, 
