@@ -77,7 +77,6 @@ def sql_setup(logger, settings, action_or_audit):
                                                          settings[DB_SERVER],
                                                          settings[DB_PORT],
                                                          settings[DB_NAME])
-    print(connection_string)
     engine = create_engine(connection_string)
     meta = MetaData()
     logger.debug('Making connection to ' + str(engine))
@@ -169,7 +168,7 @@ def export_audit_sql(logger, settings, audit_json, get_started):
         session.close()
         logger.warning('Something went wrong. Here are the details: {}'.format(ex))
     except IntegrityError as ex:
-        # If the bulk insert fails, we do a slower merge
+        # If the bulk insert fails (likely due to a duplicate), we do a slower merge
         logger.warning('Duplicate found, attempting to update')
         session.rollback()
         for row in df_dict:
@@ -202,16 +201,20 @@ def save_exported_actions_to_db(logger, actions_array, settings, get_started):
     :param export_path:     path to directory for exports
     :param actions_array:   Array of action objects to be converted to CSV and saved to disk
     """
-    engine = get_started[1]
-    actions_db = get_started[4]
+
+    actions_db = get_started[2]
+    session = get_started[1]
+
+    # engine = get_started[1]
+    # actions_db = get_started[4]
 
     if not actions_array:
         # logger.info('No actions returned after ' + get_last_successful_actions_export(logger, settings[CONFIG_NAME]))
         logger.info('No actions returned.')
         return
     logger.info('Exporting ' + str(len(actions_array)) + ' actions')
-    Session = sessionmaker(bind=engine)
-    session = Session()
+    # Session = sessionmaker(bind=engine)
+    # session = Session()
     bulk_actions = []
     for action in actions_array:
         action_as_list = transform_action_object_to_list(action)
